@@ -17,6 +17,7 @@ from easybuttons import *
 from execute import Execute
 from easygsettings import EasyGSettings
 from easyfiles import *
+import recentHelper as RecentHelper
 
 import matemenu
 
@@ -157,6 +158,7 @@ class pluginclass( object ):
     @print_timing
     def __init__( self, mintMenuWin, toggleButton, de ):
         self.mintMenuWin = mintMenuWin
+        RecentHelper.mintMenuWin = mintMenuWin
 
         self.mainMenus = [ ]
 
@@ -222,7 +224,7 @@ class pluginclass( object ):
 
        # self.searchButton.connect( "button_release_event", self.SearchWithButton )
         try:
-        # GSettings stuff
+            # GSettings stuff
             self.settings = EasyGSettings( "com.linuxmint.mintmenu.plugins.applications" )
             self.GetGSettingsEntries()
             self.settings.notifyAdd( "icon-size", self.changeIconSize )
@@ -247,7 +249,7 @@ class pluginclass( object ):
             print detail
         self.currentFavCol = 0
         self.favorites = []
-
+        
         self.content_holder.set_size_request( self.width, self.height )
         self.categoriesBox.set_size_request( self.width / 3, -1 )
         self.applicationsBox.set_size_request( self.width / 2, -1 )
@@ -280,8 +282,7 @@ class pluginclass( object ):
 
         self.icon_theme = Gtk.IconTheme.get_default();
         self.icon_theme.connect("changed", self.on_icon_theme_changed)
-
-
+        
     def refresh_apt_cache(self):
         if self.useAPT:
             os.system("mkdir -p %s/.linuxmint/mintMenu/" % home)
@@ -433,6 +434,7 @@ class pluginclass( object ):
 
         self.Todos()
         self.buildFavorites()
+        RecentHelper.buildRecentApps()
         self.RebuildPlugin()
 
     def GetGSettingsEntries( self ):
@@ -587,7 +589,7 @@ class pluginclass( object ):
             suggestionButton = SuggestionButton("list-add", self.iconSize, "")
             suggestionButton.connect("clicked", self.search_wikipedia)
             suggestionButton.set_text(_("Search Wikipedia for %s") % text)
-            suggestionButton.set_image("/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.ico")
+            suggestionButton.set_image("/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.png")
             self.applicationsBox.add(suggestionButton)
             self.suggestions.append(suggestionButton)
 
@@ -792,7 +794,7 @@ class pluginclass( object ):
                             # We're restricting our search...
                             self.add_search_suggestions(text)
                             #if (len(self.current_results) > 0):
-                                #self.add_apt_filter_results_sync(self.current_results, text)
+                            #self.add_apt_filter_results_sync(self.current_results, text)
                             #else:
                             GLib.timeout_add (300, self.add_apt_filter_results, text)
                         else:
@@ -1017,7 +1019,7 @@ class pluginclass( object ):
 
             menuItem = Gtk.ImageMenuItem(_("Search Wikipedia"))
             img = Gtk.Image()
-            img.set_from_file('/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.ico')
+            img.set_from_file('/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.png')
             menuItem.set_image(img)
             menuItem.connect("activate", self.search_wikipedia)
             menu.append(menuItem)
@@ -1105,7 +1107,7 @@ class pluginclass( object ):
     def search_wikipedia(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "+")
-        os.system("xdg-open \"http://%s.wikipedia.org/wiki/Special:Search?search=%s\" &" % (self.lang, text))
+        os.system("xdg-open \"https://%s.wikipedia.org/wiki/Special:Search?search=%s\" &" % (self.lang, text))
         self.mintMenuWin.hide()
 
     def search_dictionary(self, widget):
@@ -1116,31 +1118,31 @@ class pluginclass( object ):
     def search_mint_tutorials(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "%20")
-        os.system("xdg-open \"http://community.linuxmint.com/index.php/tutorial/search/0/" + text + "\" &")
+        os.system("xdg-open \"https://community.linuxmint.com/index.php/tutorial/search/0/" + text + "\" &")
         self.mintMenuWin.hide()
 
     def search_mint_ideas(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "%20")
-        os.system("xdg-open \"http://community.linuxmint.com/index.php/idea/search/0/" + text + "\" &")
+        os.system("xdg-open \"https://community.linuxmint.com/index.php/idea/search/0/" + text + "\" &")
         self.mintMenuWin.hide()
 
     def search_mint_users(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "%20")
-        os.system("xdg-open \"http://community.linuxmint.com/index.php/user/search/0/" + text + "\" &")
+        os.system("xdg-open \"https://community.linuxmint.com/index.php/user/search/0/" + text + "\" &")
         self.mintMenuWin.hide()
 
     def search_mint_hardware(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "%20")
-        os.system("xdg-open \"http://community.linuxmint.com/index.php/hardware/search/0/" + text + "\" &")
+        os.system("xdg-open \"https://community.linuxmint.com/index.php/hardware/search/0/" + text + "\" &")
         self.mintMenuWin.hide()
 
     def search_mint_software(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "%20")
-        os.system("xdg-open \"http://community.linuxmint.com/index.php/software/search/0/" + text + "\" &")
+        os.system("xdg-open \"https://community.linuxmint.com/index.php/software/search/0/" + text + "\" &")
         self.mintMenuWin.hide()
 
     def add_to_desktop(self, widget, desktopEntry):
@@ -1288,6 +1290,7 @@ class pluginclass( object ):
     def do_plugin( self ):
         self.Todos()
         self.buildFavorites()
+        RecentHelper.buildRecentApps()
 
     # Scroll button into view
     def scrollItemIntoView( self, widget, event = None ):
@@ -1361,7 +1364,7 @@ class pluginclass( object ):
                 favButton.connect( "popup-menu", self.favPopup )
                 favButton.connect( "button-press-event", self.favPopup )
                 favButton.connect( "focus-in-event", self.scrollItemIntoView )
-                favButton.connect( "clicked", lambda w: self.mintMenuWin.hide() )
+                favButton.connect( "clicked", RecentHelper.applicationButtonClicked )
 
                 self.mintMenuWin.setTooltip( favButton, favButton.getTooltip() )
                 favButton.type = "location"
@@ -1478,7 +1481,7 @@ class pluginclass( object ):
                 self.favoritesReorder( favButton.position, position )
 
             self.favoritesSave()
-
+     
     def favoritesRemove( self, position ):
         tmp = self.favorites[ position ]
         self.favorites.remove( self.favorites[ position ] )
@@ -1683,7 +1686,7 @@ class pluginclass( object ):
                         self.mintMenuWin.setTooltip( item["button"], item["button"].getTooltip() )
                         item["button"].connect( "button-press-event", self.menuPopup )
                         item["button"].connect( "focus-in-event", self.scrollItemIntoView )
-                        item["button"].connect( "clicked", lambda w: self.mintMenuWin.hide() )
+                        item["button"].connect( "clicked", RecentHelper.applicationButtonClicked )
                         if self.activeFilter[0] == 0:
                             item["button"].filterText( self.activeFilter[1] )
                         else:
